@@ -1,5 +1,6 @@
 {-# LANGUAGE CPP #-}
 {-# LANGUAGE DeriveDataTypeable #-}
+{-# LANGUAGE LambdaCase #-}
 {-|
 
 -}
@@ -10,6 +11,7 @@ import Data.Data (Data)
 import Data.Default
 import Data.Typeable (Typeable)
 import Data.List (intercalate)
+import Data.Maybe (fromMaybe)
 import System.Environment
 
 import Hledger.Cli hiding (progname,version,prognameandversion)
@@ -45,13 +47,13 @@ uiflags = [
   -- ,flagNone ["no-elide"] (setboolopt "no-elide") "don't compress empty parent accounts on one line"
  ]
 
---uimode :: Mode [([Char], [Char])]
-uimode =  (mode "hledger-ui" [("command","ui")]
+--uimode :: Mode RawOpts
+uimode =  (mode "hledger-ui" (setopt "command" "ui" def)
             "browse accounts, postings and entries in a full-window curses interface"
             (argsFlag "[PATTERNS]") []){
               modeGroupFlags = Group {
                                 groupUnnamed = uiflags
-                               ,groupHidden = []
+                               ,groupHidden = hiddenflags
                                ,groupNamed = [(generalflagsgroup1)]
                                }
              ,modeHelpSuffix=[
@@ -85,17 +87,18 @@ rawOptsToUIOpts rawopts = checkUIOpts <$> do
              ,cliopts_ = cliopts
              }
 
--- | Should transactions dated later than today be included ? 
+-- | Should transactions dated later than today be included ?
 -- Like flat/tree mode, there are three states, and the meaning of default can vary by command.
 data PresentOrFutureOpt = PFDefault | PFPresent | PFFuture deriving (Eq, Show, Data, Typeable)
 instance Default PresentOrFutureOpt where def = PFDefault
 
 presentorfutureopt :: RawOpts -> PresentOrFutureOpt
-presentorfutureopt rawopts =
-  case reverse $ filter (`elem` ["present","future"]) $ map fst rawopts of
-    ("present":_) -> PFPresent
-    ("future":_)  -> PFFuture
-    _             -> PFDefault
+presentorfutureopt =
+  fromMaybe PFDefault . choiceopt parse where
+    parse = \case
+      "present" -> Just PFPresent
+      "future"  -> Just PFFuture
+      _         -> Nothing
 
 checkUIOpts :: UIOpts -> UIOpts
 checkUIOpts opts =
@@ -106,10 +109,10 @@ checkUIOpts opts =
 
 -- XXX some refactoring seems due
 getHledgerUIOpts :: IO UIOpts
---getHledgerUIOpts = processArgs uimode >>= return . decodeRawOpts >>= rawOptsToUIOpts
+--getHledgerUIOpts = processArgs uimode >>= return >>= rawOptsToUIOpts
 getHledgerUIOpts = do
   args <- getArgs >>= expandArgsAt
-  let args' = replaceNumericFlags args 
+  let args' = replaceNumericFlags args
   let cmdargopts = either usageError id $ process uimode args'
-  rawOptsToUIOpts $ decodeRawOpts cmdargopts 
+  rawOptsToUIOpts cmdargopts
 
