@@ -35,15 +35,15 @@ toggleCleared :: UIState -> UIState
 toggleCleared ui@UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}} =
   ui{aopts=uopts{cliopts_=copts{reportopts_=reportOptsToggleStatusSomehow Cleared copts ropts}}}
 
--- TODO testing different status toggle styles 
+-- TODO testing different status toggle styles
 
--- | Generate zero or more indicators of the status filters currently active, 
+-- | Generate zero or more indicators of the status filters currently active,
 -- which will be shown comma-separated as part of the indicators list.
 uiShowStatus :: CliOpts -> [Status] -> [String]
 uiShowStatus copts ss =
   case style of
-    -- in style 2, instead of "Y, Z" show "not X" 
-    Just 2 | length ss == numstatuses-1 
+    -- in style 2, instead of "Y, Z" show "not X"
+    Just 2 | length ss == numstatuses-1
       -> map (("not "++). showstatus) $ sort $ complement ss  -- should be just one
     _ -> map showstatus $ sort ss
   where
@@ -55,7 +55,7 @@ uiShowStatus copts ss =
 
 reportOptsToggleStatusSomehow :: Status -> CliOpts -> ReportOpts -> ReportOpts
 reportOptsToggleStatusSomehow s copts ropts =
-  case maybeintopt "status-toggles" $ rawopts_ copts of 
+  case maybeintopt "status-toggles" $ rawopts_ copts of
      Just 2 -> reportOptsToggleStatus2 s ropts
      Just 3 -> reportOptsToggleStatus3 s ropts
 --     Just 4 -> reportOptsToggleStatus4 s ropts
@@ -78,7 +78,7 @@ reportOptsToggleStatus1 s ropts@ReportOpts{statuses_=ss}
 reportOptsToggleStatus2 s ropts@ReportOpts{statuses_=ss}
   | ss == [s]            = ropts{statuses_=complement [s]}
   | ss == complement [s] = ropts{statuses_=[]}
-  | otherwise            = ropts{statuses_=[s]}  -- XXX assume only three values 
+  | otherwise            = ropts{statuses_=[s]}  -- XXX assume only three values
 
 -- 3 UPC toggles each X
 reportOptsToggleStatus3 s ropts@ReportOpts{statuses_=ss}
@@ -108,6 +108,32 @@ toggleEmpty ui@UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=rop
   where
     toggleEmpty ropts = ropts{empty_=not $ empty_ ropts}
 
+-- | Show primary amounts, not cost or value.
+clearCostValue :: UIState -> UIState
+clearCostValue ui@UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}} =
+  ui{aopts=uopts{cliopts_=copts{reportopts_=ropts{value_ = plog "clearing value mode" Nothing}}}}
+
+-- | Toggle between showing the primary amounts or costs.
+toggleCost :: UIState -> UIState
+toggleCost ui@UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}} =
+  ui{aopts=uopts{cliopts_=copts{reportopts_=ropts{value_ = valuationToggleCost $ value_ ropts}}}}
+
+-- | Toggle between showing primary amounts or default valuation.
+toggleValue :: UIState -> UIState
+toggleValue ui@UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}} =
+  ui{aopts=uopts{cliopts_=copts{reportopts_=ropts{
+    value_ = plog "toggling value mode to" $ valuationToggleValue $ value_ ropts}}}}
+
+-- | Basic toggling of -B/cost, for hledger-ui.
+valuationToggleCost :: Maybe ValuationType -> Maybe ValuationType
+valuationToggleCost (Just (AtCost _)) = Nothing
+valuationToggleCost _                 = Just $ AtCost Nothing
+
+-- | Basic toggling of -V, for hledger-ui.
+valuationToggleValue :: Maybe ValuationType -> Maybe ValuationType
+valuationToggleValue (Just (AtDefault _)) = Nothing
+valuationToggleValue _                    = Just $ AtDefault Nothing
+
 -- | Toggle between flat and tree mode. If current mode is unspecified/default, assume it's flat.
 toggleTree :: UIState -> UIState
 toggleTree ui@UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}} =
